.. _api:

#############
API Reference
#############

This is the API documentation for the scikit-bayes package.

.. currentmodule:: skbn

Bayesian Classifiers
====================

Mixed Naive Bayes
-----------------

.. autosummary::
   :toctree: generated/
   :template: class.rst

   MixedNB

.. _ande_api:

AnDE Family
-----------

Averaged n-Dependence Estimators and related classifiers.

.. autosummary::
   :toctree: generated/
   :template: class.rst

   AnDE
   AnJE
   ALR
   WeightedAnDE


Utilities
=========

.. autosummary::
   :toctree: generated/
   :template: functions.rst

     utils.discovery.all_estimators
     utils.discovery.all_displays
     utils.discovery.all_functions
